summaryrefslogtreecommitdiff
path: root/auto_prepend.php
diff options
context:
space:
mode:
Diffstat (limited to 'auto_prepend.php')
-rw-r--r--auto_prepend.php11
1 files changed, 8 insertions, 3 deletions
diff --git a/auto_prepend.php b/auto_prepend.php
index d026017..6bcd03c 100644
--- a/auto_prepend.php
+++ b/auto_prepend.php
@@ -92,13 +92,18 @@ function EDX()
/**
* Return a text in the selected language
* @param $label Label of text to return
* @param $language Optional language to return text in
* @return Localized text string
*/
-function T($label, $language = null, $dummy = null)
+function T($label, $language = null, $values = null)
{
it_text::init();
- return $GLOBALS['it_text']->text($label, $language, $dummy);
+
+ if (is_array($language)) # Need to swap params?
+ list($language, $values) = array($values, $language);
+
+ return is_array($values) ? $GLOBALS['it_text']->etext($label, array_map(array("it_html", "Q"), $values), $language) : $GLOBALS['it_text']->text($label, $language);
}
/**
@@ -92,13 +92,18 @@ function EDX()
* Return a text in the selected language
* @param $label Label of text to return
- * @param $language Optional language to return text in
+ * @param $language Optional value array or language string
+ * @param $values Optional value array or language string
* @return Localized text string
*/